@@ -61,11 +61,16 @@ def f_drawdown(assets, X, previous_w, cost_parameters, w):
     return to_minimize + transaction_costs
 
 class AbstractAssembler(ABC):
-    def __init__(self, starting_date=None, running_date = None, drop_token=None, dropbox_backup = True, features_pkl_file_name='features.pkl', macro_features_directory='features_macro', returns_pkl_file_name='returns.pkl', local_root_directory='../data/', user='napoleon',
+    def __init__(self, starting_date=None, running_date = None, drop_token=None, dropbox_backup = True, features_pkl_file_suffix='_features.pkl', macro_features_directory='features_macro', returns_pkl_file_suffix='_returns.pkl', local_root_directory='../data/', user='napoleon',
                  supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', transaction_costs = None):
         super().__init__()
-        self.features_pkl_file_name = features_pkl_file_name
-        self.returns_pkl_file_name = returns_pkl_file_name
+
+        self.features_pkl_file_suffix = features_pkl_file_suffix
+        self.returns_pkl_file_suffix = returns_pkl_file_suffix
+
+        self.features_pkl_file_name = running_date.strftime('%d_%b_%Y')+features_pkl_file_suffix
+        self.returns_pkl_file_name = running_date.strftime('%d_%b_%Y')+returns_pkl_file_suffix
+
         self.macro_features_directory=macro_features_directory
         self.local_root_directory = local_root_directory
         self.user = user
