@@ -22,6 +22,8 @@ from napoleontoolbox.forecasting import max_occurence_model_wrapper
 from napoleontoolbox.forecasting import erc_allocation_model_wrapper
 from napoleontoolbox.forecasting import mvp_allocation_model_wrapper
 from napoleontoolbox.forecasting import mvp_uc_allocation_model_wrapper
+from napoleontoolbox.forecasting import ivp_allocation_model_wrapper
+from napoleontoolbox.forecasting import hrp_allocation_model_wrapper
 
 from abc import ABC, abstractmethod
 
@@ -30,7 +32,7 @@ def instantiate_model(method):
     if method == 'standard':
         return linear_model_wrapper.LinearModel()
     if method == 'lasso':
-        return lasso_model_wrapper.LassoModel
+        return lasso_model_wrapper.LassoModel()
 #        alpha = 0.1
 #        self.model = Lasso(alpha=alpha, fit_intercept=False, max_iter=5000)
     if method == 'lgbm':
@@ -51,6 +53,10 @@ def instantiate_model(method):
         return mvp_allocation_model_wrapper.MVP_Allocation_Model()
     if method == 'mvp_uc_allocation_model':
         return mvp_uc_allocation_model_wrapper.MVP_uc_Allocation_Model()
+    if method == 'ivp_allocation_model':
+        return ivp_allocation_model_wrapper.IVP_Allocation_Model()
+    if method == 'hrp_allocation_model':
+        return hrp_allocation_model_wrapper.HRP_Allocation_Model()
 
 
 
