@@ -54,7 +54,7 @@ class AbstractRunner(ABC):
 
 class ForecasterRunner(AbstractRunner):
     def runTrial(self, saver, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
-        continuous_saving_key, two_states_saving_key, three_states_saving_key = saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
+        continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo = saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
 
         check_run_existence, table_number = saver.checkRunExistence(continuous_saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(continuous_saving_key)
@@ -99,7 +99,7 @@ class ForecasterRunner(AbstractRunner):
         model = forecasting_utility.instantiate_model(method=chosen_method)
 
         # Compute rolling weights
-        forecasted_series, features_importances, discrete_two_states_forecasting_series, discrete_three_states_forecasting_series = time_series_forecasting.rolling_forecasting(
+        forecasted_series, features_importances, discrete_two_states_forecasting_series, discrete_two_states_forecasting_series_lo, discrete_three_states_forecasting_series, discrete_three_states_forecasting_series_lo = time_series_forecasting.rolling_forecasting(
             model,
             X,
             y,
@@ -119,8 +119,12 @@ class ForecasterRunner(AbstractRunner):
         forecasted_series[np.isinf(forecasted_series)] = 0
         discrete_two_states_forecasting_series[np.isnan(discrete_two_states_forecasting_series)] = 0
         discrete_two_states_forecasting_series[np.isinf(discrete_two_states_forecasting_series)] = 0
+        discrete_two_states_forecasting_series_lo[np.isnan(discrete_two_states_forecasting_series_lo)] = 0
+        discrete_two_states_forecasting_series_lo[np.isinf(discrete_two_states_forecasting_series_lo)] = 0
         discrete_three_states_forecasting_series[np.isnan(discrete_three_states_forecasting_series)] = 0
         discrete_three_states_forecasting_series[np.isinf(discrete_three_states_forecasting_series)] = 0
+        discrete_three_states_forecasting_series_lo[np.isnan(discrete_three_states_forecasting_series_lo)] = 0
+        discrete_three_states_forecasting_series_lo[np.isinf(discrete_three_states_forecasting_series_lo)] = 0
         y[np.isnan(y)] = 0
         y[np.isinf(y)] = 0
         matrix = confusion_matrix(y > 0, discrete_two_states_forecasting_series)
@@ -134,9 +138,12 @@ class ForecasterRunner(AbstractRunner):
         print('confusion matrix')
         print(matrix)
 
+        transaction_cost = True
+        if self.frequence=='minutely':
+            transaction_cost = False
 
         #saving the continuous signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series, y_true = y, transaction_cost=True, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -147,7 +154,7 @@ class ForecasterRunner(AbstractRunner):
 
 
         #saving the 2 states signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred= discrete_two_states_forecasting_series , y_true = y, transaction_cost=True, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred= discrete_two_states_forecasting_series , y_true = y, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
@@ -156,13 +163,35 @@ class ForecasterRunner(AbstractRunner):
         print(sharpe_strat)
         saver.saveAll(two_states_saving_key, perf_df)
 
+        # saving the 2 states signal long only
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_two_states_forecasting_series_lo, y_true=y,
+                                                              transaction_cost=transaction_cost, print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
+        print('underlying sharpe')
+        print(sharpe_under)
+        print('strat sharpe')
+        print(sharpe_strat)
+        saver.saveAll(two_states_saving_key_lo, perf_df)
+
 
         #saving the 3 states signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series, y_true = y, transaction_cost=True, print_turnover=False)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
         print(sharpe_strat)
-        saver.saveAll(three_states_saving_key, perf_df)
\ No newline at end of file
+        saver.saveAll(three_states_saving_key, perf_df)
+
+        # saving the 3 states signal long only
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series_lo, y_true=y,
+                                                              transaction_cost=transaction_cost, print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
+        print('underlying sharpe')
+        print(sharpe_under)
+        print('strat sharpe')
+        print(sharpe_strat)
+        saver.saveAll(three_states_saving_key_lo, perf_df)
\ No newline at end of file
